Package: sunburstR
Type: Package
Title: Sunburst 'Htmlwidget'
Version: 2.1.8
Date: 2023-02-05
Authors@R: c(
      person(
        "Mike", "Bostock"
        , role = c("aut", "cph")
        , comment = "d3.js library, http://d3js.org"
      ),
      person(
        "Kerry", "Rodden"
        , role = c("aut", "cph")
        , comment = "sequences library in htmlwidgets/lib, https://gist.github.com/kerryrodden/7090426"
      ),
      person(
        "Kevin", "Warne"
        , role = c("aut", "cph")
        , comment = "d2b sunburst library in htmlwidgets/lib, https://github.com/d2bjs/d2b"
      ),
      person(
        "Kent", "Russell"
        , role = c("aut", "cre")
        , comment = "R interface"
        , email = "kent.russell@timelyportfolio.com"
      ),
      person(
        "Florian", "Breitwieser"
        , role = c("ctb")
        , comment = "R interface"
      ),
      person(
        "CJ", "Yetman"
        , role = c("ctb")
        , comment = c("R interface", ORCID = "0000-0001-5099-9500")
        , email = "cj@cjyetman.com"
      )
    )
Maintainer: Kent Russell <kent.russell@timelyportfolio.com>
URL: https://github.com/timelyportfolio/sunburstR
BugReports: https://github.com/timelyportfolio/sunburstR/issues
Description: Make interactive 'd3.js' sequence sunburst diagrams in R with the
    convenience and infrastructure of an 'htmlwidget'.
License: MIT + file LICENSE
Imports: d3r (>= 0.6.9), dplyr, htmlwidgets, htmltools
Suggests: jsonlite, knitr, markdown, pipeR, testthat, tidyr (>= 0.7.0),
        rmarkdown
Enhances: treemap
RoxygenNote: 7.2.3
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2023-02-05 18:28:19 UTC; kentr
Author: Mike Bostock [aut, cph] (d3.js library, http://d3js.org),
  Kerry Rodden [aut, cph] (sequences library in htmlwidgets/lib,
    https://gist.github.com/kerryrodden/7090426),
  Kevin Warne [aut, cph] (d2b sunburst library in htmlwidgets/lib,
    https://github.com/d2bjs/d2b),
  Kent Russell [aut, cre] (R interface),
  Florian Breitwieser [ctb] (R interface),
  CJ Yetman [ctb] (R interface, <https://orcid.org/0000-0001-5099-9500>)
Repository: CRAN
Date/Publication: 2023-02-05 23:20:02 UTC
Built: R 4.2.0; ; 2023-02-06 01:26:03 UTC; unix
