<!-- badges: start -->
[![R-CMD-check](https://github.com/timelyportfolio/sunburstR/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/timelyportfolio/sunburstR/actions/workflows/R-CMD-check.yaml)
[![CRAN status](https://www.r-pkg.org/badges/version/sunburstR)](https://CRAN.R-project.org/package=sunburstR)
<!-- badges: end -->

### Help Me/Pay Me to Use, Improve, and Extend

`sunburstR` has already seen extensive use in many projects across multiple domains.  If you have any interest in collaborating with me on this project or applying `sunburstR`, please let me know (see [Time Isn't Money](https://buildingwidgets.com/2016-12-09_post_break/)).


# sunburstR

Easily make these interactive `d3.js` sequence sunburst charts in `R` originally modeled on this [example](https://gist.github.com/kerryrodden/7090426) from Kerry Rodden.  In addition, `sunburstr` provides another beautiful and functional version using [`d2b`](https://github.com/d2bjs/d2b) from Kevin Warne.

### Examples

See the [examples](https://github.com/timelyportfolio/sunburstR/tree/master/inst/examples).

### Improve/Iterate

These are still far from feature-complete.  I would love your input, feedback, and comments.

### Code of Conduct

Please note that this project is released with a [Contributor Code of Conduct](https://github.com/timelyportfolio/sunburstR/blob/master/CONDUCT.md). By participating in this project you agree to abide by its terms.
